'=====================================================================================
'  modExportToHTML
'  color syntax control helper module...used to do exporting to html
'=====================================================================================
'  Created By: Marc Cramer
'  Published Date: 1/16/2003
'  Legal Copyright: Marc Cramer  1/16/2003
'=====================================================================================

Imports System
Imports System.IO
Imports System.Text
Imports System.Drawing.ColorTranslator

Module modExportToHtml
	'=========================================================================================
	Public Function GetExportCode(ByVal IncludeHeader As Boolean, ByVal IncludeFooter As Boolean, ByVal ColorCode As Boolean, ByVal RTF As RichTextBox, ByVal KeyWordColor As Color, ByVal CommentColor As Color, ByVal NormalTextColor As Color, ByVal KeywordList As String, ByVal KeywordDelimiter As String, ByVal CommentCharacter As String, ByVal TextFont As Font) As String
		Dim FileContent As New StringBuilder()
		Dim HTML_Header As String = "<html><head><title>Source Code</title></head><body style=""font-family:" & TextFont.Name & "; font-size:" & TextFont.SizeInPoints & "pt;"">"
		Dim HTML_Footer As String = "</body></html>"

		If ColorCode = True Then
			Dim KeyWordTag As String = "<font color=""" & ColorTranslator.ToHtml(KeyWordColor) & """>"
			Dim CommentTag As String = "<font color=""" & ColorTranslator.ToHtml(CommentColor) & """>"
			Dim NormalTag As String = "<font color=""" & ColorTranslator.ToHtml(NormalTextColor) & """>"
			Dim EndTag As String = "</font>"

			With FileContent
				If IncludeHeader = True Then .Append(HTML_Header)
				.Append(HTML_Body(RTF, KeyWordTag, CommentTag, NormalTag, EndTag, KeywordList, KeywordDelimiter, CommentCharacter))
				If IncludeFooter = True Then .Append(HTML_Footer)
			End With
		Else
			' no coloring need so just save as preformatted html file
			With FileContent
				If IncludeHeader = True Then .Append(HTML_Header)
				.Append(Replace(Replace(RTF.Text, Chr(10), "<br>"), Chr(9), "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"))
				If IncludeFooter = True Then .Append(HTML_Footer)
			End With
		End If
		GetExportCode = FileContent.ToString
	End Function	  'GetExportCode(ByVal IncludeHeader As Boolean, ByVal IncludeFooter As Boolean, ByVal ColorCode As Boolean, ByVal RTF As RichTextBox, ByVal KeyWordColor As Color, ByVal CommentColor As Color, ByVal NormalTextColor As Color, ByVal KeywordList As String, ByVal KeywordDelimiter As String, ByVal CommentCharacter As String, ByVal TextFont As Font) As String
	'=========================================================================================
	Public Sub ExportCode(ByVal FilePath As String, ByVal ColorCode As Boolean, ByVal RTF As RichTextBox, ByVal KeyWordColor As Color, ByVal CommentColor As Color, ByVal NormalTextColor As Color, ByVal KeywordList As String, ByVal KeywordDelimiter As String, ByVal CommentCharacter As String, ByVal TextFont As Font)
		' routine to export code to html
		Dim FileContent As New StringBuilder()
		Dim HTML_Header As String = "<html><head><title>Source Code</title></head><body style=""font-family:" & TextFont.Name & "; font-size:" & TextFont.SizeInPoints & "pt;"">"
		Dim HTML_Footer As String = "</body></html>"

		If ColorCode = True Then
			Dim KeyWordTag As String = "<font color=""" & ColorTranslator.ToHtml(KeyWordColor) & """>"
			Dim CommentTag As String = "<font color=""" & ColorTranslator.ToHtml(CommentColor) & """>"
			Dim NormalTag As String = "<font color=""" & ColorTranslator.ToHtml(NormalTextColor) & """>"
			Dim EndTag As String = "</font>"

			With FileContent
				.Append(HTML_Header)
				.Append(HTML_Body(RTF, KeyWordTag, CommentTag, NormalTag, EndTag, KeywordList, KeywordDelimiter, CommentCharacter))
				.Append(HTML_Footer)
			End With
		Else
			' no coloring need so just save as preformatted html file
			With FileContent
				.Append(HTML_Header)
				.Append(Replace(Replace(RTF.Text, Chr(10), "<br>"), Chr(9), "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"))
				.Append(HTML_Footer)
			End With
		End If
		WriteFile(FilePath, FileContent.ToString)
	End Sub	  'ExportCode(ByVal FilePath As String, ByVal ColorCode As Boolean, ByVal RTF As RichTextBox, ByVal KeyWordColor As Color, ByVal CommentColor As Color, ByVal NormalTextColor As Color, ByVal KeywordList As String, ByVal KeywordDelimiter As String, ByVal CommentCharacter As String)
	'=====================================================================================
	Private Sub WriteFile(ByVal FilePath As String, ByVal FileContent As String)
		Dim MyFileStream As New FileStream(FilePath, FileMode.Create, FileAccess.Write)
		Dim MyStreamWriter As New StreamWriter(MyFileStream)
		With MyStreamWriter
			.BaseStream.Seek(0, SeekOrigin.End)
			.Write(FileContent)
			.Flush()
			.Close()
		End With
		MyFileStream.Close()
		MyStreamWriter = Nothing
		MyFileStream = Nothing
	End Sub	  'WriteFile(ByVal FilePath As String, ByVal FileContent As String)
	'=====================================================================================
	Private Function HTML_Body(ByVal RTF As RichTextBox, ByVal KeywordTag As String, ByVal CommentTag As String, ByVal NormalTag As String, ByVal EndTag As String, ByVal KeywordList As String, ByVal KeywordDelimiter As String, ByVal CommentCharacter As String) As String
		'parse and color the code
		Dim StringBuilder As New StringBuilder()
		Dim Sentence As String
		Dim Word As String
		Dim LineCounter As Integer
		Dim LineCount As Integer
		Dim Counter As Integer
		Dim CurrentChr As String
		Dim CurrentLineText As String
		Dim CurrentLineTextLength As Integer
		Dim KeywordArray() As String = Split(KeywordList, KeywordDelimiter)
		Dim CommentFlag As Boolean
		Dim QuoteFlag As Boolean

		LockUpdate(True)
		With RTF
			'parse line by line
			LineCount = .Lines.GetUpperBound(0)
			For LineCounter = 0 To LineCount
				' take out the "enter key" and tack a space on the end for processing
				CurrentLineText = Replace(Replace(.Lines(LineCounter), Chr(10), ""), Chr(9), "     ") & " "
				CurrentLineTextLength = Len(CurrentLineText)
				' reset our variables
				Word = ""
				Sentence = ""
				' lets process a character at a time
				For Counter = 1 To CurrentLineTextLength
					CurrentChr = Mid(CurrentLineText, Counter, 1)
					If CurrentChr = Chr(32) Or CurrentChr = "." Or CurrentChr = "(" Or CurrentChr = ")" Then
						' found a word so process it
						If IsKeyword(KeywordArray, Word) = True Then
							' its a keyword so color it
							Word = KeywordTag & Word & EndTag
						End If
						' tack the word onto our sentence
						Sentence = Sentence & Word & CurrentChr
						' reset our variable
						Word = ""
					Else
						' we have a quote so set our flag
						If CurrentChr = Chr(34) Then QuoteFlag = Not QuoteFlag
						' allows and check for multi character comment delimeters
						If CurrentChr & Mid(CurrentLineText, Counter, Len(CommentCharacter) - 1) = CommentCharacter Then
							If QuoteFlag = False Then
								' found our comment and not contained in quotes so everything else on line is comment
								Word = Word & CommentTag & Mid(CurrentLineText, Counter) & EndTag
								Sentence = Sentence & Word & Chr(32)
								' reset our comment flag and drop out of loop
								CommentFlag = False
								Exit For
							End If
						End If
						' update for html...
						If CurrentChr = Chr(34) Then CurrentChr = "&quot;"
						If CurrentChr = Chr(38) Then CurrentChr = "&amp;"
						If CurrentChr = Chr(60) Then CurrentChr = "&lt;"
						If CurrentChr = Chr(62) Then CurrentChr = "&gt;"
						' build the word...
						Word = Word & CurrentChr
					End If
				Next Counter
				' tack on "enter key" and append to string builder
				Sentence = Replace(Sentence, "     ", "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;") & "<br>"
				StringBuilder.Append(Sentence)
			Next LineCounter
			'clear the rtf and replace the html characters and set the text into it
			.Clear()
			.Text = StringBuilder.ToString

		End With
		LockUpdate(False)
		HTML_Body = RTF.Text
	End Function	  'HTML_Body(ByVal RTF As RichTextBox, ByVal KeywordTag As String, ByVal CommentTag As String, ByVal NormalTag As String, ByVal EndTag As String, ByVal KeywordList As String, ByVal CommentCharacter As String) As String
	'=====================================================================================
	Private Function IsKeyword(ByVal KeyWordArray As Array, ByVal Word As String) As Boolean
		'Word = Replace(Word, ";", "")
		'Word = Replace(Word, "(", "")
		'Word = Replace(Word, ")", "")

		If Array.BinarySearch(KeyWordArray, Trim(Word)) < 0 Then
			IsKeyword = False
		Else
			IsKeyword = True
		End If
	End Function	  'IsKeyword(ByVal KeyWordArray As Array, ByVal Word As String) As Boolean
	'=====================================================================================
End Module
